Learn R Programming

binGroup2 (version 1.2.3)

formula.gtReg: Extract the model formula from a fitted group testing model

Description

Extract the model formula from objects of class "gtReg" returned by gtReg.

Usage

# S3 method for gtReg
formula(x, ...)

Arguments

x

An object of class "gtReg", created by gtReg, from which the model formula is to be extracted.

...

not currently used.

Value

Model formula extracted from the object object.

Examples

Run this code
# NOT RUN {
data(hivsurv)
fit1 <- gtReg(formula = groupres ~ AGE * EDUC.,
              data = hivsurv, groupn = gnum,
              linkf = "probit")
formula(x = fit1)
# }

Run the code above in your browser using DataLab