Learn R Programming

binGroup2 (version 1.2.3)

pmf: Access the testing probability mass function returned from an object

Description

pmf is a generic function that extracts the probability mass function from an object (if available) that contains information aboout a testing configuration.

Usage

pmf(object, ...)

Arguments

object

An object from which the probability mass function is to be extracted.

...

Additional arguments to be passed to pmf.

See Also

pmf.halving and pmf.Sterrett

Examples

Run this code
# NOT RUN {
res <- halving(p = rep(0.01, 10), Sp = 1, Se = 1,
               stages = 2, order.p = TRUE)
pmf.halving(res)
# }

Run the code above in your browser using DataLab