Print method for objects of class "OTC" returned by
OTC1 or OTC2.
# S3 method for OTC
print(x, ...)an object of class "OTC", providing the optimal testing configuration results for a group testing algorithm.
Additional arguments to be passed to print (e.g.,
digits to be passed to round for appropriate rounding).
A print out of the algorithm, testing configuration, expected number of tests, expected number of tests per individual, and accuracy measures for individuals and for the overall algorithm.