Learn R Programming

binGroup2 (version 1.2.3)

print.Sterrett: Print method for objects of class "Sterrett"

Description

Print method for objects of class "Sterrett" created by the Sterrett function.

Usage

# S3 method for Sterrett
print(x, ...)

Arguments

x

An object of class "Sterrett" (Sterrett).

...

Additional arguments to be passed to print. Currently only digits to be passed to signif for appropriate rounding.

Value

A print out of the PMF, expected testing expenditure and variance of testing expenditure resulting from Sterrett.