Learn R Programming

binGroup2 (version 1.2.3)

print.gtReg: Print method for gtReg

Description

Print method for objects obtained by gtReg.

Usage

# S3 method for gtReg
print(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

x

An object of class "gtReg" created by gtReg.

digits

digits for rounding.

...

currently not used.

Value

A print out of the function call, coefficients, and the null and residual deviance and degrees of freedom.