Learn R Programming

binGroup2 (version 1.2.3)

print.halving: Print method for objects of class "halving"

Description

Print method for objects of class "halving" created by the halving function.

Usage

# S3 method for halving
print(x, ...)

Arguments

x

An object of class "halving" (halving).

...

Additional arguments to be passed to print. Currently only digits to be passed to signif for appropriate rounding.

Value

A print out of the PMF, expected testing expenditure and variance of testing expenditure resulting from halving.