Print method for objects of class "opChar" returned by
operatingCharacteristics1 (opChar1) or
operatingCharacteristics2 (opChar2).
# S3 method for opChar
print(x, ...)an object of class "opChar", providing the calculated operating characteristics for a group testing algorithm.
Additional arguments to be passed to print (e.g.,
digits to be passed to round for appropriate rounding).
A print out of the algorithm, testing configuration, expected number of tests, expected number of tests per individual, and accuracy measures for individuals and for the overall algorithm.