Learn R Programming

binGroup2 (version 1.2.3)

ExpTests: Access the expected number of tests from an object

Description

ExpTests is a generic function that extracts the expected number of tests from an object that contains information aboout a testing configuration.

Usage

ExpTests(object, ...)

Arguments

object

An object for which a summary of the expected number of tests is desired.

...

Additional arguments to be passed to ExpTests.

Value

The value return depends on the class of its object. See the documentation for the corresponding method functions.

See Also

ExpTests.opChar and ExpTests.OTC

Examples

Run this code
# NOT RUN {
# Find the optimal testing configuration for
#   non-informative two-stage hierarchical testing.
res1 <- OTC1(algorithm = "D2", p = 0.01, Se = 0.99, Sp = 0.99,
             group.sz = 2:100, obj.fn = c("ET", "MAR", "GR1"),
             weights = matrix(data = c(1,1), nrow = 1, ncol = 2))
ExpTests(res1)
# }

Run the code above in your browser using DataLab