powered by
Extract the model formula from objects of class "gtReg" returned by gtReg.
gtReg
# S3 method for gtReg formula(x, ...)
An object of class "gtReg", created by gtReg, from which the model formula is to be extracted.
not currently used.
Model formula extracted from the object object.
# NOT RUN { data(hivsurv) fit1 <- gtReg(formula = groupres ~ AGE * EDUC., data = hivsurv, groupn = gnum, linkf = "probit") formula(x = fit1) # }
Run the code above in your browser using DataLab