Learn R Programming

binGroup2 (version 1.2.3)

pmf.Sterrett: Extract probability mass function (PMF) from group testing results

Description

Extract the probability mass function from group testing results for the Sterrett algorithm (objects of class "Sterrett" returned by Sterrett).

Usage

# S3 method for Sterrett
pmf(object, ...)

Arguments

object

An object of class "Sterrett", created by Sterrett, from which the PMF is to be extracted.

...

currently not used.

Value

Data frame containing the probability mass function extracted from the object object.

Examples

Run this code
# NOT RUN {
set.seed(1231)
p.vec <- rbeta(n = 8, shape1 = 1, shape2 = 10)
res <- Sterrett(p = p.vec, Sp = 0.90, Se = 0.95)
pmf(res)
# }

Run the code above in your browser using DataLab