Print method for objects of class "designEst" created by
designEst.
# S3 method for designEst
print(x, ...)an object of class "designEst" created by designEst.
additional arguments to be passed to print.
Currently only digits to be passed to signif for
appropriate rounding.
A print out detailing whether the bias restriction was violated, whether the maximum allowed group size was reached, and the minimum MSE and associated group size, expected value, variance, and bias.